/*
 * Copyright 2002-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.security.config.annotation.web

import org.springframework.security.config.annotation.web.builders.HttpSecurity
import org.springframework.security.config.annotation.web.configurers.PasswordManagementConfigurer

/**
 * A Kotlin DSL to configure [HttpSecurity] password management
 * using idiomatic Kotlin code.
 *
 * @author Evgeniy Cheban
 * @property changePasswordPage the change password page.
 * @since 5.6
 */
@SecurityMarker
class PasswordManagementDsl {
    var changePasswordPage: String? = null

    internal fun get(): (PasswordManagementConfigurer<HttpSecurity>) -> Unit {
        return { passwordManagement ->
            changePasswordPage?.also { passwordManagement.changePasswordPage(changePasswordPage) }
        }
    }
}
