/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.security.test.context;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Mockito.mock;

public class TestSecurityContextHolderTests {

	private SecurityContext context;

	@BeforeEach
	public void setup() {
		this.context = SecurityContextHolder.createEmptyContext();
	}

	@AfterEach
	public void cleanup() {
		TestSecurityContextHolder.clearContext();
	}

	@Test
	public void clearContextClearsBoth() {
		SecurityContextHolder.setContext(this.context);
		TestSecurityContextHolder.setContext(this.context);
		TestSecurityContextHolder.clearContext();
		assertThat(SecurityContextHolder.getContext()).isNotSameAs(this.context);
		assertThat(TestSecurityContextHolder.getContext()).isNotSameAs(this.context);
	}

	@Test
	public void getContextDefaultsNonNull() {
		assertThat(TestSecurityContextHolder.getContext()).isNotNull();
		assertThat(SecurityContextHolder.getContext()).isNotNull();
	}

	@Test
	public void setContextSetsBoth() {
		TestSecurityContextHolder.setContext(this.context);
		assertThat(TestSecurityContextHolder.getContext()).isSameAs(this.context);
		assertThat(SecurityContextHolder.getContext()).isSameAs(this.context);
	}

	@Test
	public void setContextWithAuthentication() {
		Authentication authentication = mock(Authentication.class);
		TestSecurityContextHolder.setAuthentication(authentication);
		assertThat(TestSecurityContextHolder.getContext().getAuthentication()).isSameAs(authentication);
	}

}
